@@ -14,12 +14,10 @@ import os
 import tempfile
 import uuid
 
-import fixtures
-
 from gnocchiclient import auth
 from gnocchiclient import client
-from gnocchiclient.tests.functional import base
 from gnocchiclient import utils
+from gnocchiclient.tests.functional import base
 
 
 class MetricClientTest(base.ClientTestBase):
@@ -77,6 +75,31 @@ class MetricClientTest(base.ClientTestBase):
                               u" --limit 2")
         self.assertEqual(2, len(json.loads(result)))
 
+    def test_metric_measures_exhautic_format(self):
+        ap_name = str(uuid.uuid4())
+        # PREPARE AN ARCHIVE POLICY
+        self.gnocchi("archive-policy", params="create " + ap_name +
+                     " --back-window 0 -d granularity:1s,points:86400")
+        # CREATE METRIC
+        metric_name = str(uuid.uuid4())
+        result = self.gnocchi(
+            u'metric', params=u"create"
+            u" --archive-policy-name " + ap_name + " " + metric_name)
+        metric = json.loads(result)
+
+        # MEASURES ADD
+        self.gnocchi('measures',
+                     params=("add %s "
+                             "--measure 'now@42' ")
+                     % metric["id"], has_output=False)
+
+        # MEASURES SHOW
+        result = self.gnocchi('measures', params="show --refresh " +
+                              metric["id"])
+        measures = json.loads(result)
+        self.assertEqual(1, len(measures))
+        self.assertEqual(42, measures[0]['value'])
+
     def test_metric_measures_show_tz(self):
         ap_name = str(uuid.uuid4())
         # PREPARE AN ARCHIVE POLICY
@@ -97,7 +120,10 @@ class MetricClientTest(base.ClientTestBase):
                      % metric["id"], has_output=False)
 
         # MEASURES SHOW
-        self.useFixture(fixtures.EnvironmentVariable("TZ", "Europe/Paris"))
+        def _delete_tz():
+            os.unsetenv("TZ")
+        self.addCleanup(_delete_tz)
+        os.putenv("TZ", "Europe/Paris")
         result = self.gnocchi('measures', params="show --refresh " +
                               metric["id"])
         measures = json.loads(result)
